# -*- coding: utf-8 -*-
# flake8: noqa
'''Модели для работы с облачными серверами'''
from .cloud import (
    VDS, VDSArray, VDSResponse, VDSDelete
)
